@@ -40,8 +40,6 @@
 
 #include <libedata-book/libedata-book.h>
 
-#include "lzx/ews-oal-decompress.h"
-
 #include "server/e-ews-item-change.h"
 #include "server/e-ews-message.h"
 #include "server/e-ews-connection.h"
@@ -52,6 +50,8 @@
 
 #include "e-book-backend-ews.h"
 #include "ews-oab-decoder.h"
+#include "ews-oab-decompress.h"
+
 
 #define d(x) x
 
@@ -851,7 +851,7 @@ ebews_set_notes_changes (ESoapMessage *message,
 
 	if (g_strcmp0 (old_notes, new_notes) != 0) {
 		convert_contact_property_to_updatexml (
-				message, "Body", new_notes ?: "", "item", "BodyType", "Text");
+				message, "Body", new_notes ? new_notes : "", "item", "BodyType", "Text");
 	}
 
 	g_free (old_notes);
@@ -918,7 +918,7 @@ static const struct field_element_mapping {
 	{ E_CONTACT_IM_AIM, ELEMENT_TYPE_COMPLEX, "ImAddresses", NULL, ebews_populate_ims, ebews_set_ims, ebews_set_im_changes },
 	{ E_CONTACT_TITLE, ELEMENT_TYPE_SIMPLE, "JobTitle", e_ews_item_get_job_title},
 	{ E_CONTACT_MANAGER, ELEMENT_TYPE_SIMPLE, "Manager", e_ews_item_get_manager},
-	{ E_CONTACT_MANAGER, ELEMENT_TYPE_SIMPLE, "OfficeLocation", e_ews_item_get_office_location},
+	{ E_CONTACT_OFFICE, ELEMENT_TYPE_SIMPLE, "OfficeLocation", e_ews_item_get_office_location},
 	{ E_CONTACT_SPOUSE, ELEMENT_TYPE_SIMPLE, "Profession", e_ews_item_get_profession},
 	{ E_CONTACT_SPOUSE, ELEMENT_TYPE_SIMPLE, "SpouseName", e_ews_item_get_spouse_name},
 	{ E_CONTACT_FAMILY_NAME, ELEMENT_TYPE_SIMPLE, "Surname", e_ews_item_get_surname},
@@ -1175,7 +1175,7 @@ e_book_backend_ews_remove_contacts (EBookBackend *backend,
 		return;
 	}
 
-	for (l = (GSList *) id_list; l != NULL; l = g_slist_next (id_list))
+	for (l = (GSList *) id_list; l != NULL; l = g_slist_next (l))
 		copy = g_slist_prepend (copy, g_strdup ((gchar *) l->data));
 	copy = g_slist_reverse (copy);
 
@@ -1719,45 +1719,17 @@ e_book_backend_ews_build_restriction (const gchar *query,
 
 /************* GAL sync ***********************/
 
-static gboolean
-ews_gal_needs_update (EBookBackendEws *cbews,
-                      EwsOALDetails *full,
-                      GError **error)
-{
-	EBookBackendEwsPrivate *priv = cbews->priv;
-	guint32 seq;
-	gboolean ret = FALSE;
-	gchar *tmp;
-
-	if (!priv->summary)
-		return FALSE;
-
-	tmp = e_book_backend_sqlitedb_get_key_value (priv->summary, priv->folder_id, "seq", error);
-	if (!tmp)
-		goto exit;
-
-	sscanf (tmp, "%"G_GUINT32_FORMAT, &seq);
-	if (seq < full->seq)
-		ret = TRUE;
-
-	d (printf ("Gal needs update: %d (local: %d, remote: %d)\n",
-		   ret, seq, full->seq);)
-exit:
-	g_free (tmp);
-	return ret;
-}
-
 static gchar *
-ews_download_full_gal (EBookBackendEws *cbews,
+ews_download_gal_file (EBookBackendEws *cbews,
                        EwsOALDetails *full,
                        GCancellable *cancellable,
                        GError **error)
 {
 	EBookBackendEwsPrivate *priv = cbews->priv;
 	EEwsConnection *oab_cnc;
-	gchar *full_url, *oab_url, *cache_file = NULL;
+	gchar *full_url, *oab_url;
 	const gchar *cache_dir;
-	gchar *comp_cache_file = NULL, *uncompress_file = NULL;
+	gchar *download_path = NULL;
 	gchar *password;
 	CamelEwsSettings *ews_settings;
 
@@ -1767,7 +1739,7 @@ ews_download_full_gal (EBookBackendEws *cbews,
 	oab_url = g_strndup (priv->oab_url, strlen (priv->oab_url) - 7);
 	full_url = g_strconcat (oab_url, full->filename, NULL);
 	cache_dir = e_book_backend_get_cache_dir (E_BOOK_BACKEND (cbews));
-	comp_cache_file = g_build_filename (cache_dir, full->filename, NULL);
+	download_path = g_build_filename (cache_dir, full->filename, NULL);
 
 	oab_cnc = e_ews_connection_new (full_url, ews_settings);
 
@@ -1775,30 +1747,127 @@ ews_download_full_gal (EBookBackendEws *cbews,
 	e_ews_connection_set_password (oab_cnc, password);
 	g_free (password);
 
-	if (!e_ews_connection_download_oal_file_sync (
-		oab_cnc, comp_cache_file, NULL, NULL, cancellable, error))
-		goto exit;
-
-	cache_file = g_strdup_printf ("%s-%d.oab", priv->folder_name, full->seq);
-	uncompress_file = g_build_filename (cache_dir, cache_file, NULL);
-	if (!oal_decompress_v4_full_detail_file (comp_cache_file, uncompress_file, error)) {
-		g_free (uncompress_file);
-		uncompress_file = NULL;
+	if (!e_ews_connection_download_oal_file_sync (oab_cnc, download_path,
+						      NULL, NULL,
+						      cancellable, error)) {
+		g_free (download_path);
+		download_path = NULL;
 		goto exit;
 	}
 
-	d (g_print ("OAL file decompressed %s \n", uncompress_file);)
+	d (g_print ("OAL file downloaded %s\n", download_path);)
 
-exit:
-	if (comp_cache_file)
-		g_unlink (comp_cache_file);
+ exit:
 	g_object_unref (oab_cnc);
 	g_free (oab_url);
 	g_free (full_url);
-	g_free (comp_cache_file);
-	g_free (cache_file);
 
-	return uncompress_file;
+	return download_path;
+}
+
+static gchar *
+ews_download_full_gal (EBookBackendEws *cbews,
+                       EwsOALDetails *full,
+                       GCancellable *cancellable,
+                       GError **error)
+{
+	EBookBackendEwsPrivate *priv = cbews->priv;
+	const gchar *cache_dir;
+	gchar *lzx_path, *oab_file, *oab_path;
+
+	lzx_path = ews_download_gal_file (cbews, full, cancellable, error);
+	if (!lzx_path)
+		return NULL;
+
+	cache_dir = e_book_backend_get_cache_dir (E_BOOK_BACKEND (cbews));
+	oab_file = g_strdup_printf ("%s-%d.oab", priv->folder_name, full->seq);
+	oab_path = g_build_filename (cache_dir, oab_file, NULL);
+	if (!ews_oab_decompress_full (lzx_path, oab_path, error)) {
+		g_free (oab_path);
+		oab_path = NULL;
+		goto exit;
+	}
+
+	d (g_print ("OAL file decompressed %s \n", oab_path);)
+
+exit:
+	if (lzx_path) {
+		g_unlink (lzx_path);
+		g_free (lzx_path);
+	}
+	g_free (oab_file);
+	return oab_path;
+}
+
+static gchar *
+ews_download_gal (EBookBackendEws *cbews, EwsOALDetails *full, GSList *deltas, guint32 seq,
+		  GCancellable *cancellable, GError **error)
+{
+#ifdef USE_MSPACK
+	EBookBackendEwsPrivate *priv = cbews->priv;
+	GSList *p;
+	gchar *thisoab = NULL;
+	const gchar *cache_dir;
+
+	cache_dir = e_book_backend_get_cache_dir (E_BOOK_BACKEND (cbews));
+
+	thisoab = e_book_backend_sqlitedb_get_key_value (priv->summary, priv->folder_id,
+							 "oab-filename", NULL);
+	if (!thisoab)
+		goto full;
+
+	for (p = deltas; p; p = p->next) {
+		EwsOALDetails *det = p->data;
+		GError *local_error = NULL;
+		gchar *oab_file, *lzx_path, *nextoab;
+
+		seq++;
+		if (det->seq != seq)
+			break;
+
+		lzx_path = ews_download_gal_file (cbews, det, cancellable, NULL);
+		if (!lzx_path)
+			break;
+
+		oab_file = g_strdup_printf ("%s-%d.oab", priv->folder_name, seq);
+		nextoab = g_build_filename (cache_dir, oab_file, NULL);
+		g_free (oab_file);
+
+		ews_oab_decompress_patch (lzx_path, thisoab, nextoab, &local_error);
+
+		/* Free the LZX file */
+		g_unlink (lzx_path);
+		g_free (lzx_path);
+
+		/* Free the previous OAB file */
+		g_unlink (thisoab);
+		g_free (thisoab);
+
+		thisoab = nextoab;
+
+		/* For once we are *allowed* to use the error instead of having to
+		 * check the return value of the function. It's our *own* error. */
+		if (local_error) {
+			d (g_print ("Failed to apply incremental patch: %s\n",
+				    local_error->message));
+			g_error_free (local_error);
+			break;
+		}
+
+		d (g_print ("Created %s from delta\n", thisoab));
+
+		if (seq == full->seq)
+			return thisoab;
+	}
+
+	if (thisoab) {
+		g_unlink (thisoab);
+		g_free (thisoab);
+	}
+ full:
+#endif
+	d (printf ("Ewsgal: Downloading full gal \n"));
+	return ews_download_full_gal (cbews, full, cancellable, error);
 }
 
 static gboolean
@@ -1873,6 +1942,13 @@ ews_gal_store_contact (EContact *contact,
 		e_book_backend_notify_complete (E_BOOK_BACKEND (data->cbews));
 }
 
+static gint det_sort_func (gconstpointer _a, gconstpointer _b)
+{
+	const EwsOALDetails *a = _a, *b = _b;
+
+	return a->seq - b->seq;
+}
+
 static gboolean
 ews_replace_gal_in_db (EBookBackendEws *cbews,
                        const gchar *filename,
@@ -1929,9 +2005,15 @@ ebews_start_gal_sync (gpointer data)
 	GError *error = NULL;
 	EEwsConnection *oab_cnc;
 	GSList *full_l = NULL;
+	GSList *deltas = NULL;
 	gboolean ret = TRUE;
+	gboolean is_populated;
 	gchar *uncompressed_filename = NULL;
 	gchar *password;
+	gchar *old_etag = NULL, *etag = NULL;
+	gchar *seq;
+	guint32 old_seq = 0;
+	guint32 delta_size = 0;
 	CamelEwsSettings *ews_settings;
 
 	cbews = (EBookBackendEws *) data;
@@ -1946,8 +2028,22 @@ ebews_start_gal_sync (gpointer data)
 
 	d (printf ("Ewsgal: Fetching oal full details file \n");)
 
+	is_populated = e_book_backend_sqlitedb_get_is_populated (priv->summary, priv->folder_id, NULL);
+	if (is_populated) {
+		gchar *tmp;
+		old_etag = e_book_backend_sqlitedb_get_key_value (
+			priv->summary, priv->folder_id, "etag", NULL);
+		tmp = e_book_backend_sqlitedb_get_key_value (
+			priv->summary, priv->folder_id, "seq", NULL);
+		if (tmp)
+			old_seq = strtoul(tmp, NULL, 10);
+		else
+			is_populated = FALSE;
+		g_free (tmp);
+	}
+
 	if (!e_ews_connection_get_oal_detail_sync (
-		oab_cnc, priv->folder_id, "Full", &full_l,
+		oab_cnc, priv->folder_id, NULL, old_etag, &full_l, &etag,
 		priv->cancellable, &error)) {
 		ret = FALSE;
 		goto exit;
@@ -1960,41 +2056,71 @@ ebews_start_gal_sync (gpointer data)
 	if (full_l == NULL)
 		goto exit;
 
-	full = (EwsOALDetails *) full_l->data;
-	/* TODO fetch differential updates if available instead of downloading the whole GAL */
-	if (!e_book_backend_sqlitedb_get_is_populated (priv->summary, priv->folder_id, NULL) || ews_gal_needs_update (cbews, full, &error)) {
-		gchar *seq;
+	while (full_l) {
+		EwsOALDetails *det = full_l->data;
 
-		d (printf ("Ewsgal: Downloading full gal \n");)
-		uncompressed_filename = ews_download_full_gal (cbews, full, priv->cancellable, &error);
-		if (error) {
-			ret = FALSE;
-			goto exit;
-		}
-
-		d (printf ("Ewsgal: Removing old gal \n");)
-		/* remove old_gal_file */
-		ret = ews_remove_old_gal_file (cbews, &error);
-		if (!ret) {
-			goto exit;
-		}
-
-		d (printf ("Ewsgal: Replacing old gal with new gal contents in db \n");)
-		ret = ews_replace_gal_in_db (cbews, uncompressed_filename, priv->cancellable, &error);
-		if (!ret)
-			goto exit;
-
-		seq = g_strdup_printf ("%"G_GUINT32_FORMAT, full->seq);
-		ret = e_book_backend_sqlitedb_set_key_value (priv->summary, priv->folder_id, "seq", seq, &error);
-		g_free (seq);
-
-		if (!ret) {
-			e_book_backend_sqlitedb_delete_addressbook (priv->summary, priv->folder_id, &error);
-			goto exit;
+		/* Throw away anything older than we already have */
+		if (det->seq <= old_seq) {
+			ews_oal_details_free (det);
+		} else if (!strcmp (det->type, "Full")) {
+			if (full)
+				ews_oal_details_free (full);
+			full = det;
+		} else if (is_populated && !strcmp (det->type, "Diff")) {
+			delta_size += det->size;
+			deltas = g_slist_insert_sorted (deltas, det, det_sort_func);
+		} else {
+			ews_oal_details_free (det);
 		}
+		full_l = g_slist_remove (full_l, det);
 	}
 
-	d (printf ("Ews gal: sync successfull complete \n");)
+	if (!full)
+		goto exit;
+
+	/* If the deltas would be bigger, just download the new full file */
+	if (delta_size > full->size) {
+		g_slist_free_full (deltas, (GDestroyNotify) ews_oal_details_free);
+		deltas = NULL;
+	}
+
+	uncompressed_filename = ews_download_gal (cbews, full, deltas, old_seq, priv->cancellable, &error);
+	if (!uncompressed_filename) {
+		ret = FALSE;
+		goto exit;
+	}
+
+	d (printf ("Ewsgal: Removing old gal \n");)
+	/* remove old_gal_file */
+	ret = ews_remove_old_gal_file (cbews, &error);
+	if (!ret) {
+		goto exit;
+	}
+
+	d (printf ("Ewsgal: Replacing old gal with new gal contents in db \n");)
+	ret = ews_replace_gal_in_db (cbews, uncompressed_filename, priv->cancellable, &error);
+	if (!ret)
+		goto exit;
+
+	e_book_backend_sqlitedb_set_key_value (priv->summary, priv->folder_id, "etag", etag ? etag : "", NULL);
+	if (e_book_backend_sqlitedb_set_key_value (priv->summary, priv->folder_id,
+						   "oab-filename", uncompressed_filename,
+						   NULL)) {
+		/* Don't let it get deleted */
+		g_free (uncompressed_filename);
+		uncompressed_filename = NULL;
+	}
+
+	seq = g_strdup_printf ("%"G_GUINT32_FORMAT, full->seq);
+	ret = e_book_backend_sqlitedb_set_key_value (priv->summary, priv->folder_id, "seq", seq, &error);
+	g_free (seq);
+
+	if (!ret) {
+		e_book_backend_sqlitedb_delete_addressbook (priv->summary, priv->folder_id, &error);
+		goto exit;
+	}
+
+	d (printf ("Ews gal: sync successful complete \n");)
 
 exit:
 	if (error) {
@@ -2002,18 +2128,21 @@ exit:
 		g_clear_error (&error);
 	}
 
+	g_free (old_etag);
+	g_free (etag);
+
 	/* preserve  the oab file once we are able to decode the differential updates */
 	if (uncompressed_filename) {
 		g_unlink (uncompressed_filename);
 		g_free (uncompressed_filename);
 	}
 
-	if (full_l) {
-		g_free (full->sha);
-		g_free (full->filename);
-		g_free (full);
-		g_slist_free (full_l);
-	}
+	if (full)
+		ews_oal_details_free (full);
+	if (deltas)
+		g_slist_free_full (deltas, (GDestroyNotify) ews_oal_details_free);
+	if (full_l)
+		g_slist_free_full (full_l, (GDestroyNotify) ews_oal_details_free);
 
 	g_object_unref (oab_cnc);
 	return ret;
@@ -2586,9 +2715,7 @@ fetch_from_offline (EBookBackendEws *ews,
 	for (l = contacts; l != NULL; l = g_slist_next (l)) {
 		EbSdbSearchData *s_data = (EbSdbSearchData *) l->data;
 
-		/* reset vcard to NULL as it would be free'ed in prefiltered_vcard function */
 		e_data_book_view_notify_update_prefiltered_vcard (book_view, s_data->uid, s_data->vcard);
-		s_data->vcard = NULL;
 
 		e_book_backend_sqlitedb_search_data_free (s_data);
 	}
@@ -2899,23 +3026,23 @@ e_book_backend_ews_get_backend_property (EBookBackend *backend,
 
 		for (i = 0; i < G_N_ELEMENTS (mappings); i++)
 			if (mappings[i].element_type == ELEMENT_TYPE_SIMPLE)
-				fields = g_slist_append (fields, g_strdup (e_contact_field_name (mappings[i].field_id)));
+				fields = g_slist_append (fields, (gpointer) e_contact_field_name (mappings[i].field_id));
 
 		for (i = 0; i < G_N_ELEMENTS (phone_field_map); i++)
-			fields = g_slist_append (fields, g_strdup (e_contact_field_name (phone_field_map[i].field)));
+			fields = g_slist_append (fields, (gpointer) e_contact_field_name (phone_field_map[i].field));
 
-		fields = g_slist_append (fields, g_strdup (e_contact_field_name (E_CONTACT_FULL_NAME)));
-		fields = g_slist_append (fields, g_strdup (e_contact_field_name (E_CONTACT_NICKNAME)));
-		fields = g_slist_append (fields, g_strdup (e_contact_field_name (E_CONTACT_FAMILY_NAME)));
-		fields = g_slist_append (fields, g_strdup (e_contact_field_name (E_CONTACT_EMAIL_1)));
-		fields = g_slist_append (fields, g_strdup (e_contact_field_name (E_CONTACT_EMAIL_2)));
-		fields = g_slist_append (fields, g_strdup (e_contact_field_name (E_CONTACT_EMAIL_3)));
-		fields = g_slist_append (fields, g_strdup (e_contact_field_name (E_CONTACT_ADDRESS_WORK)));
-		fields = g_slist_append (fields, g_strdup (e_contact_field_name (E_CONTACT_ADDRESS_HOME)));
-		fields = g_slist_append (fields, g_strdup (e_contact_field_name (E_CONTACT_ADDRESS_OTHER)));
-		fields = g_slist_append (fields, g_strdup (e_contact_field_name (E_CONTACT_BIRTH_DATE)));
+		fields = g_slist_append (fields, (gpointer) e_contact_field_name (E_CONTACT_FULL_NAME));
+		fields = g_slist_append (fields, (gpointer) e_contact_field_name (E_CONTACT_NICKNAME));
+		fields = g_slist_append (fields, (gpointer) e_contact_field_name (E_CONTACT_FAMILY_NAME));
+		fields = g_slist_append (fields, (gpointer) e_contact_field_name (E_CONTACT_EMAIL_1));
+		fields = g_slist_append (fields, (gpointer) e_contact_field_name (E_CONTACT_EMAIL_2));
+		fields = g_slist_append (fields, (gpointer) e_contact_field_name (E_CONTACT_EMAIL_3));
+		fields = g_slist_append (fields, (gpointer) e_contact_field_name (E_CONTACT_ADDRESS_WORK));
+		fields = g_slist_append (fields, (gpointer) e_contact_field_name (E_CONTACT_ADDRESS_HOME));
+		fields = g_slist_append (fields, (gpointer) e_contact_field_name (E_CONTACT_ADDRESS_OTHER));
+		fields = g_slist_append (fields, (gpointer) e_contact_field_name (E_CONTACT_BIRTH_DATE));
 
-		fields = g_slist_append (fields, g_strdup (e_contact_field_name (E_CONTACT_NOTE)));
+		fields = g_slist_append (fields, (gpointer) e_contact_field_name (E_CONTACT_NOTE));
 
 		fields_str = e_data_book_string_slist_to_comma_string (fields);
 
