@@ -74,5 +74,7 @@
 #define EWS_PT_MEMBER_OF_DLS		0x8008101E
 #define EWS_PT_TRUNCATED_PROPS		0x68051003
 #define EWS_PT_THUMBNAIL_PHOTO		0x8C9E0102
+#define EWS_PT_X509_CERT		0x8c6a1102
+#define EWS_PT_SEND_RICH_INFO		0x3a40000b
 
 #endif /* _EWS_OAB_PROPS */
