@@ -87,6 +87,10 @@ camel_ews_utils_build_folder_info (CamelEwsStore *store,
 	return fi;
 }
 
+static void
+add_folder_to_summary (CamelEwsStore *store,
+                       EEwsFolder *folder);
+
 static void
 sync_deleted_folders (CamelEwsStore *store,
                       GSList *deleted_folders)
@@ -171,6 +175,13 @@ sync_updated_folders (CamelEwsStore *store,
 		folder_name = camel_ews_store_summary_get_folder_full_name (
 			ews_summary, fid->id, NULL);
 
+		if (!folder_name) {
+			/* in case the folder is not in the local store summary,
+			   just add it as a new folder */
+			add_folder_to_summary (store, ews_folder);
+			continue;
+		}
+
 		pfid = e_ews_folder_get_parent_id (ews_folder);
 		display_name = g_strdup (e_ews_folder_get_name (ews_folder));
 
@@ -499,18 +510,10 @@ form_email_string_from_mb (EEwsConnection *cnc,
 {
 	if (mb) {
 		GString *str;
-		gchar *email = NULL;
+		const gchar *email = NULL;
 
-		if (g_strcmp0 (mb->routing_type, "EX") == 0) {
-			e_ews_connection_ex_to_smtp_sync (
-				cnc, EWS_PRIORITY_MEDIUM,
-				mb->name, mb->email, &email,
-				cancellable, NULL);
-
-			/* do not scare users with EX addresses */
-			if (!email)
-				email = g_strdup ("");
-		}
+		if (g_strcmp0 (mb->routing_type, "EX") == 0)
+			email = e_ews_item_util_strip_ex_address (mb->email);
 
 		str = g_string_new ("");
 		if (mb->name && mb->name[0]) {
@@ -524,8 +527,6 @@ form_email_string_from_mb (EEwsConnection *cnc,
 			g_string_append (str, ">");
 		}
 
-		g_free (email);
-
 		return camel_pstring_add (g_string_free (str, FALSE), TRUE);
 	} else
 	       return camel_pstring_strdup ("");
