@@ -26,12 +26,7 @@
 #include <gtk/gtk.h>
 #include <glib/gi18n-lib.h>
 
-#include <misc/e-dateedit.h>
-#include <e-util/e-dialog-utils.h>
-#include <libevolution-utils/e-alert-sink.h>
-#include <libevolution-utils/e-alert-dialog.h>
-#include <misc/e-activity-bar.h>
-#include <misc/e-alert-bar.h>
+#include <e-util/e-util.h>
 #include <mail/e-mail-backend.h>
 
 #include "server/camel-ews-settings.h"
