@@ -105,6 +105,13 @@ typedef enum {
 	EWS_SPECIFIED_OCCURRENCE_ONLY
 } EwsAffectedTaskOccurrencesType;
 
+typedef enum {
+	E_EWS_BODY_TYPE_ANY,
+	E_EWS_BODY_TYPE_BEST,
+	E_EWS_BODY_TYPE_HTML,
+	E_EWS_BODY_TYPE_TEXT
+} EEwsBodyType;
+
 typedef struct {
 	gchar *as_url;
 	gchar *oab_url;
@@ -122,6 +129,7 @@ typedef struct {
 } EwsOAL;
 
 typedef struct {
+	gchar *type;
 	guint32 seq;
 	guint32 ver;
 	guint32 size;
@@ -321,6 +329,7 @@ void		e_ews_connection_get_items	(EEwsConnection *cnc,
 						 const gchar *additional_props,
 						 gboolean include_mime,
 						 const gchar *mime_directory,
+						 EEwsBodyType body_type,
 						 ESoapProgressFn progress_fn,
 						 gpointer progress_data,
 						 GCancellable *cancellable,
@@ -338,6 +347,7 @@ gboolean	e_ews_connection_get_items_sync	(EEwsConnection *cnc,
 						 const gchar *additional_props,
 						 gboolean include_mime,
 						 const gchar *mime_directory,
+						 EEwsBodyType body_type,
 						 GSList **items,
 						 ESoapProgressFn progress_fn,
 						 gpointer progress_data,
@@ -748,12 +758,15 @@ gboolean	e_ews_connection_get_oal_detail_sync
 						(EEwsConnection *cnc,
 						 const gchar *oal_id,
 						 const gchar *oal_element,
+						 const gchar *old_etag,
 						 GSList **elements,
+						 gchar **etag,
 						 GCancellable *cancellable,
 						 GError **error);
 void		e_ews_connection_get_oal_detail	(EEwsConnection *cnc,
 						 const gchar *oal_id,
 						 const gchar *oal_element,
+						 const gchar *etag,
 						 GCancellable *cancellable,
 						 GAsyncReadyCallback callback,
 						 gpointer user_data);
@@ -761,6 +774,7 @@ gboolean	e_ews_connection_get_oal_detail_finish
 						(EEwsConnection *cnc,
 						 GAsyncResult *result,
 						 GSList **elements,
+						 gchar **etag,
 						 GError **error);
 
 void		e_ews_connection_get_free_busy	(EEwsConnection *cnc,
