@@ -8,19 +8,19 @@
 /* Test result of created folder id */
 extern EwsFolderId *folder_id;
 
-void set_oof_settings_test_run ();
-void get_oof_settings_test_run ();
-void connection_tests_run ();
-void op_tests_run ();
-void cuditem_tests_run ();
-void autocompletion_tests_run ();
-void createfolder_tests_run ();
+void oof_settings_submit_test_run (void);
+void oof_settings_new_test_run (void);
+void connection_tests_run (void);
+void op_tests_run (void);
+void cuditem_tests_run (void);
+void autocompletion_tests_run (void);
+void createfolder_tests_run (void);
 void deletefolder_tests_run (gconstpointer data);
-void get_attachments_tests_run ();
-void get_delegate_tests_run ();
+void get_attachments_tests_run (void);
+void get_delegate_tests_run (void);
 
 static void
-finalize_test_data ()
+finalize_test_data (void)
 {
 	if (folder_id) {
 		e_ews_folder_id_free (folder_id);
@@ -38,8 +38,8 @@ gint main (gint argc, gchar *argv[])
 
 	/*Register tests*/
 	g_test_add_func ("/libews/connections", connection_tests_run);
-	g_test_add_func ("/libews/setoofsettings", set_oof_settings_test_run);
-	g_test_add_func ("/libews/getoofsettings", get_oof_settings_test_run);
+	g_test_add_func ("/libews/oofsettingssubmit", oof_settings_submit_test_run);
+	g_test_add_func ("/libews/oofsettingsnew", oof_settings_new_test_run);
 	g_test_add_func ("/libews/autocompletion", autocompletion_tests_run);
 
 	g_test_add_func ("/libews/syncfolder", op_tests_run);
@@ -50,8 +50,9 @@ gint main (gint argc, gchar *argv[])
 
 	g_test_add_func ("/libews/cuditem", cuditem_tests_run);
 	g_test_add_func ("/libews/getdelegate", get_delegate_tests_run);
-
-	g_test_add_func ("/libews/getattachment", get_attachments_tests_run);
+	/*
+	 * g_test_add_func ("/libews/getattachment", get_attachments_tests_run);
+	 */
 
 	ret = g_test_run ();
 	finalize_test_data ();
